You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2019/08/05 09:48:24 UTC

[camel] branch master updated (c0cb9e9 -> 81cfdb0)

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git.


    from c0cb9e9  CAMEL-5832: camel-jms - JMS consumer should detect JMSReplyTo being sending to itself to avoid circular looping. Thanks to Devendra Khanolkar for the sample unit test.
     new a25c0c8  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs
     new e0ac1da  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - updated references
     new 44ba6e3  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Updated docs
     new e8d59b8  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Updated docs link and regen
     new 2fb5590  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Karaf integration test and feature updated
     new b334321  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - SB integration test updated
     new 81cfdb0  CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Removed references in comments

The 7 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 apache-camel/pom.xml                               |   4 +-
 apache-camel/src/main/descriptors/common-bin.xml   |   4 +-
 bom/camel-bom/pom.xml                              |   4 +-
 components/{camel-hdfs2 => camel-hdfs}/pom.xml     |   4 +-
 .../src/main/docs/hdfs-component.adoc}             |  32 ++--
 .../camel/component/hdfs2/HdfsComponent.java       |   2 +-
 .../component/hdfs2/HdfsCompressionCodec.java      |   0
 .../camel/component/hdfs2/HdfsConfiguration.java   |   2 +-
 .../camel/component/hdfs2/HdfsConstants.java       |   0
 .../apache/camel/component/hdfs2/HdfsConsumer.java |   0
 .../apache/camel/component/hdfs2/HdfsEndpoint.java |   2 +-
 .../camel/component/hdfs2/HdfsFileSystemType.java  |   0
 .../apache/camel/component/hdfs2/HdfsFileType.java |   0
 .../apache/camel/component/hdfs2/HdfsHeader.java   |   0
 .../org/apache/camel/component/hdfs2/HdfsInfo.java |   0
 .../camel/component/hdfs2/HdfsInfoFactory.java     |   0
 .../camel/component/hdfs2/HdfsInputStream.java     |   0
 .../camel/component/hdfs2/HdfsOsgiHelper.java      |   2 +-
 .../camel/component/hdfs2/HdfsOutputStream.java    |   0
 .../apache/camel/component/hdfs2/HdfsProducer.java |   0
 .../component/hdfs2/HdfsWritableFactories.java     |   0
 .../org/apache/camel/component/hdfs2/Holder.java   |   0
 .../apache/camel/component/hdfs2/WritableType.java |   0
 .../camel/component/hdfs2/osgi/HdfsActivator.java  |   0
 .../camel/component/hdfs2/FromFileToHdfsTest.java  |   2 +-
 .../camel/component/hdfs2/HdfsConsumerTest.java    |  36 ++--
 .../component/hdfs2/HdfsProducerConsumerTest.java  |   4 +-
 .../component/hdfs2/HdfsProducerSplitTest.java     |  10 +-
 .../camel/component/hdfs2/HdfsProducerTest.java    |  26 +--
 .../camel/component/hdfs2/HdfsTestSupport.java     |   0
 .../hdfs2/integration/HdfsAppendTest.java          |   8 +-
 .../HdfsProducerConsumerIntegrationTest.java       |  12 +-
 .../src/test/resources/hdfs-default.xml            |   0
 .../src/test/resources/hdfs-test.xml               |   0
 .../src/test/resources/log4j2.properties           |   2 +-
 components/pom.xml                                 |   2 +-
 components/readme.adoc                             |   4 +-
 .../endpoint/dsl/HdfsEndpointBuilderFactory.java   |  16 +-
 docs/components/modules/ROOT/nav.adoc              |   2 +-
 .../{hdfs2-component.adoc => hdfs-component.adoc}  |  32 ++--
 docs/user-manual/modules/ROOT/pages/index.adoc     |   2 +-
 parent/pom.xml                                     |   6 +-
 .../karaf/features/src/main/resources/features.xml |   6 +-
 .../pom.xml                                        |   6 +-
 .../springboot/HdfsComponentAutoConfiguration.java |   8 +-
 .../springboot/HdfsComponentConfiguration.java     |   4 +-
 .../src/main/resources/META-INF/LICENSE.txt        |   0
 .../src/main/resources/META-INF/NOTICE.txt         |   0
 .../src/main/resources/META-INF/spring.factories   |   1 +
 .../src/main/resources/META-INF/spring.provides    |   2 +-
 .../src/main/resources/META-INF/LICENSE.txt        | 203 ---------------------
 .../src/main/resources/META-INF/NOTICE.txt         |  11 --
 .../additional-spring-configuration-metadata.json  |  10 -
 platforms/spring-boot/components-starter/pom.xml   |   2 +-
 .../camel-spring-boot-dependencies/pom.xml         |  10 +-
 .../{CamelHdfs2Test.java => CamelHdfsTest.java}    |   6 +-
 .../{CamelHdfs2Test.java => CamelHdfsTest.java}    |   4 +-
 57 files changed, 135 insertions(+), 358 deletions(-)
 rename components/{camel-hdfs2 => camel-hdfs}/pom.xml (98%)
 rename components/{camel-hdfs2/src/main/docs/hdfs2-component.adoc => camel-hdfs/src/main/docs/hdfs-component.adoc} (92%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java (99%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsCompressionCodec.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java (99%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsConstants.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsConsumer.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java (93%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsFileSystemType.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsFileType.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsHeader.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsInfo.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsInfoFactory.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsInputStream.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java (97%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsOutputStream.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsProducer.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/HdfsWritableFactories.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/Holder.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/WritableType.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/main/java/org/apache/camel/component/hdfs2/osgi/HdfsActivator.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java (97%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java (88%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java (91%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java (85%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java (87%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/HdfsTestSupport.java (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java (93%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java (84%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/resources/hdfs-default.xml (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/resources/hdfs-test.xml (100%)
 rename components/{camel-hdfs2 => camel-hdfs}/src/test/resources/log4j2.properties (96%)
 rename docs/components/modules/ROOT/pages/{hdfs2-component.adoc => hdfs-component.adoc} (92%)
 rename platforms/spring-boot/components-starter/{camel-hdfs2-starter => camel-hdfs-starter}/pom.xml (94%)
 rename platforms/spring-boot/components-starter/{camel-hdfs2-starter => camel-hdfs-starter}/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java (95%)
 rename platforms/spring-boot/components-starter/{camel-hdfs2-starter => camel-hdfs-starter}/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java (95%)
 copy {tooling/maven/camel-package-maven-plugin => platforms/spring-boot/components-starter/camel-hdfs-starter}/src/main/resources/META-INF/LICENSE.txt (100%)
 copy {tooling/maven/camel-package-maven-plugin => platforms/spring-boot/components-starter/camel-hdfs-starter}/src/main/resources/META-INF/NOTICE.txt (100%)
 rename platforms/spring-boot/components-starter/{camel-hdfs2-starter => camel-hdfs-starter}/src/main/resources/META-INF/spring.factories (99%)
 rename platforms/spring-boot/components-starter/{camel-hdfs2-starter => camel-hdfs-starter}/src/main/resources/META-INF/spring.provides (97%)
 delete mode 100644 platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/LICENSE.txt
 delete mode 100644 platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/NOTICE.txt
 delete mode 100644 platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json
 rename tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/{CamelHdfs2Test.java => CamelHdfsTest.java} (94%)
 rename tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/{CamelHdfs2Test.java => CamelHdfsTest.java} (92%)


[camel] 02/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - updated references

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit e0ac1da5d30c0de57549a9cb07a08a0d54b93414
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 10:38:30 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - updated references
---
 apache-camel/pom.xml                               |  4 +--
 apache-camel/src/main/descriptors/common-bin.xml   |  4 +--
 bom/camel-bom/pom.xml                              |  4 +--
 .../{hdfs2-component.adoc => hdfs-component.adoc}  | 20 ++++++------
 .../camel/component/hdfs2/HdfsComponent.java       |  2 +-
 .../camel/component/hdfs2/HdfsConfiguration.java   |  2 +-
 .../apache/camel/component/hdfs2/HdfsEndpoint.java |  2 +-
 .../camel/component/hdfs2/FromFileToHdfsTest.java  |  2 +-
 .../camel/component/hdfs2/HdfsConsumerTest.java    | 36 +++++++++++-----------
 .../component/hdfs2/HdfsProducerConsumerTest.java  |  4 +--
 .../component/hdfs2/HdfsProducerSplitTest.java     | 10 +++---
 .../camel/component/hdfs2/HdfsProducerTest.java    | 26 ++++++++--------
 .../hdfs2/integration/HdfsAppendTest.java          |  8 ++---
 .../HdfsProducerConsumerIntegrationTest.java       | 12 ++++----
 .../src/test/resources/log4j2.properties           |  2 +-
 components/pom.xml                                 |  2 +-
 .../endpoint/dsl/HdfsEndpointBuilderFactory.java   | 14 ++++-----
 parent/pom.xml                                     |  4 +--
 .../springboot/HdfsComponentAutoConfiguration.java |  2 +-
 platforms/spring-boot/components-starter/pom.xml   |  1 -
 20 files changed, 80 insertions(+), 81 deletions(-)

diff --git a/apache-camel/pom.xml b/apache-camel/pom.xml
index ba58248..df4ab2b 100644
--- a/apache-camel/pom.xml
+++ b/apache-camel/pom.xml
@@ -679,7 +679,7 @@
     </dependency>
     <dependency>
       <groupId>org.apache.camel</groupId>
-      <artifactId>camel-hdfs2</artifactId>
+      <artifactId>camel-hdfs</artifactId>
       <version>${project.version}</version>
     </dependency>
     <dependency>
@@ -2188,7 +2188,7 @@
     </dependency>
     <dependency>
       <groupId>org.apache.camel</groupId>
-      <artifactId>camel-hdfs2-starter</artifactId>
+      <artifactId>camel-hdfs-starter</artifactId>
       <version>${project.version}</version>
     </dependency>
     <dependency>
diff --git a/apache-camel/src/main/descriptors/common-bin.xml b/apache-camel/src/main/descriptors/common-bin.xml
index 90abf7a..131e951 100644
--- a/apache-camel/src/main/descriptors/common-bin.xml
+++ b/apache-camel/src/main/descriptors/common-bin.xml
@@ -156,7 +156,7 @@
         <include>org.apache.camel:camel-guava-eventbus</include>
         <include>org.apache.camel:camel-hazelcast</include>
         <include>org.apache.camel:camel-hbase</include>
-        <include>org.apache.camel:camel-hdfs2</include>
+        <include>org.apache.camel:camel-hdfs</include>
         <include>org.apache.camel:camel-hipchat</include>
         <include>org.apache.camel:camel-hl7</include>
         <include>org.apache.camel:camel-http</include>
@@ -497,7 +497,7 @@
         <include>org.apache.camel:camel-guava-eventbus-starter</include>
         <include>org.apache.camel:camel-hazelcast-starter</include>
         <include>org.apache.camel:camel-hbase-starter</include>
-        <include>org.apache.camel:camel-hdfs2-starter</include>
+        <include>org.apache.camel:camel-hdfs-starter</include>
         <include>org.apache.camel:camel-hipchat-starter</include>
         <include>org.apache.camel:camel-hl7-starter</include>
         <include>org.apache.camel:camel-http-common-starter</include>
diff --git a/bom/camel-bom/pom.xml b/bom/camel-bom/pom.xml
index f1ed1c8..7033723 100644
--- a/bom/camel-bom/pom.xml
+++ b/bom/camel-bom/pom.xml
@@ -1244,12 +1244,12 @@
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
-        <artifactId>camel-hdfs2</artifactId>
+        <artifactId>camel-hdfs</artifactId>
         <version>${project.version}</version>
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
-        <artifactId>camel-hdfs2-starter</artifactId>
+        <artifactId>camel-hdfs-starter</artifactId>
         <version>${project.version}</version>
       </dependency>
       <dependency>
diff --git a/components/camel-hdfs/src/main/docs/hdfs2-component.adoc b/components/camel-hdfs/src/main/docs/hdfs-component.adoc
similarity index 97%
rename from components/camel-hdfs/src/main/docs/hdfs2-component.adoc
rename to components/camel-hdfs/src/main/docs/hdfs-component.adoc
index f42ba0e..b8880ef 100644
--- a/components/camel-hdfs/src/main/docs/hdfs2-component.adoc
+++ b/components/camel-hdfs/src/main/docs/hdfs-component.adoc
@@ -1,9 +1,9 @@
-[[hdfs2-component]]
-= HDFS2 Component
+[[hdfs-component]]
+= HDFS Component
 
 *Available as of Camel version 2.14*
 
-The HDFS2 component enables you to read and write messages from/to an
+The HDFS component enables you to read and write messages from/to an
 HDFS file system using Hadoop 2.x. HDFS is the distributed file system
 at the heart of http://hadoop.apache.org[Hadoop].
 
@@ -24,7 +24,7 @@ for this component:
 
 [source,java]
 ----------------------------------------
-hdfs2://hostname[:port][/path][?options]
+hdfs://hostname[:port][/path][?options]
 ----------------------------------------
 
 You can append query options to the URI in the following format,
@@ -41,7 +41,7 @@ a different file per split named using the configured
 UuidGenerator.
 
 
-When consuming from hdfs2 then in normal mode, a file is split into
+When consuming from hdfs then in normal mode, a file is split into
 chunks, producing a message per chunk. You can configure the size of the
 chunk using the chunkSize option. If you want to read from hdfs and
 write to a regular file using the file component, then you can use the
@@ -54,7 +54,7 @@ fileMode=Append to append each of the chunks together.
 
 
 // component options: START
-The HDFS2 component supports 3 options, which are listed below.
+The HDFS component supports 3 options, which are listed below.
 
 
 
@@ -73,10 +73,10 @@ The HDFS2 component supports 3 options, which are listed below.
 
 
 // endpoint options: START
-The HDFS2 endpoint is configured using URI syntax:
+The HDFS endpoint is configured using URI syntax:
 
 ----
-hdfs2:hostName:port/path
+hdfs:hostName:port/path
 ----
 
 with the following path and query parameters:
@@ -223,7 +223,7 @@ for example:
 
 [source,java]
 -----------------------------------------------------------------
-hdfs2://localhost/tmp/simple-file?splitStrategy=IDLE:1000,BYTES:5
+hdfs://localhost/tmp/simple-file?splitStrategy=IDLE:1000,BYTES:5
 -----------------------------------------------------------------
 
 it means: a new file is created either when it has been idle for more
@@ -249,7 +249,7 @@ split strategy.
 
 == Controlling to close file stream
 
-When using the xref:hdfs2-component.adoc[HDFS2] producer *without* a split
+When using the xref:hdfs-component.adoc[HDFS] producer *without* a split
 strategy, then the file output stream is by default closed after the
 write. However you may want to keep the stream open, and only explicitly
 close the stream later. For that you can use the header
diff --git a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java
index 3ac82f2..84af870 100644
--- a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java
+++ b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java
@@ -28,7 +28,7 @@ import org.apache.hadoop.fs.FsUrlStreamHandlerFactory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-@Component("hdfs,hdfs2")
+@Component("hdfs")
 public class HdfsComponent extends DefaultComponent {
 
     private static final Logger LOG = LoggerFactory.getLogger(HdfsComponent.class);
diff --git a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java
index 174c455..24a3818 100644
--- a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java
+++ b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java
@@ -208,7 +208,7 @@ public class HdfsConfiguration {
 
     public void parseURI(URI uri) throws URISyntaxException {
         String protocol = uri.getScheme();
-        if (!protocol.equalsIgnoreCase("hdfs2")) {
+        if (!protocol.equalsIgnoreCase("hdfs")) {
             throw new IllegalArgumentException("Unrecognized protocol: " + protocol + " for uri: " + uri);
         }
         hostName = uri.getHost();
diff --git a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java
index f848003d..3249c89 100644
--- a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java
+++ b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java
@@ -29,7 +29,7 @@ import org.apache.camel.support.ScheduledPollEndpoint;
 /**
  * For reading/writing from/to an HDFS filesystem using Hadoop 2.x.
  */
-@UriEndpoint(firstVersion = "2.14.0", scheme = "hdfs2,hdfs", title = "HDFS2", syntax = "hdfs2:hostName:port/path", label = "hadoop,file")
+@UriEndpoint(firstVersion = "2.14.0", scheme = "hdfs", title = "HDFS", syntax = "hdfs:hostName:port/path", label = "hadoop,file")
 public class HdfsEndpoint extends ScheduledPollEndpoint {
 
     @UriParam
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java
index 79a21ae..ec5c5e0 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java
@@ -106,7 +106,7 @@ public class FromFileToHdfsTest extends HdfsTestSupport {
             @Override
             public void configure() throws Exception {
                 from("file:target/inbox?delete=true")
-                    .to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/output.txt?fileSystemType=LOCAL");
+                    .to("hdfs:localhost/" + TEMP_DIR.toUri() + "/output.txt?fileSystemType=LOCAL");
             }
         };
     }
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java
index b5bc391..99c0304 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java
@@ -103,7 +103,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&chunkSize=4096&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&chunkSize=4096&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -139,10 +139,10 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=100&initialDelay=0").to("mock:result");
-                from("hdfs2://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=200&initialDelay=0").to("mock:result");
-                from("hdfs2://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=300&initialDelay=0").to("mock:result");
-                from("hdfs2://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=400&initialDelay=0").to("mock:result");
+                from("hdfs://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=100&initialDelay=0").to("mock:result");
+                from("hdfs://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=200&initialDelay=0").to("mock:result");
+                from("hdfs://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=300&initialDelay=0").to("mock:result");
+                from("hdfs://" + rootdir.toURI() + "/target/test/multiple-consumers?pattern=*.txt&fileSystemType=LOCAL&chunkSize=400&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -173,7 +173,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&chunkSize=4096&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&chunkSize=4096&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -206,7 +206,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&chunkSize=42&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&chunkSize=42&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -232,7 +232,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&chunkSize=4096&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&chunkSize=4096&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -261,7 +261,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.getParent().toUri() + "?scheduler=#myScheduler&pattern=*&fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0&readSuffix=handled")
+                from("hdfs:localhost/" + file.getParent().toUri() + "?scheduler=#myScheduler&pattern=*&fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0&readSuffix=handled")
                     .to("mock:result");
             }
         });
@@ -303,7 +303,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -336,7 +336,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -366,7 +366,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -396,7 +396,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -426,7 +426,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -456,7 +456,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -486,7 +486,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -516,7 +516,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&fileType=SEQUENCE_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
@@ -549,7 +549,7 @@ public class HdfsConsumerTest extends HdfsTestSupport {
 
         context.addRoutes(new RouteBuilder() {
             public void configure() {
-                from("hdfs2:localhost/" + file.getParent().toUri() + "?fileSystemType=LOCAL&fileType=ARRAY_FILE&initialDelay=0").to("mock:result");
+                from("hdfs:localhost/" + file.getParent().toUri() + "?fileSystemType=LOCAL&fileType=ARRAY_FILE&initialDelay=0").to("mock:result");
             }
         });
         context.start();
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java
index 501ac7d..d9ed8e0 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java
@@ -56,8 +56,8 @@ public class HdfsProducerConsumerTest extends HdfsTestSupport {
         context.addRoutes(new RouteBuilder() {
             @Override
             public void configure() {
-                from("direct:start").to("hdfs2:localhost/" + file.toUri() + "?fileSystemType=LOCAL&splitStrategy=BYTES:5,IDLE:1000");
-                from("hdfs2:localhost/" + file.toUri() + "?initialDelay=2000&fileSystemType=LOCAL&chunkSize=5").to("mock:result");
+                from("direct:start").to("hdfs:localhost/" + file.toUri() + "?fileSystemType=LOCAL&splitStrategy=BYTES:5,IDLE:1000");
+                from("hdfs:localhost/" + file.toUri() + "?initialDelay=2000&fileSystemType=LOCAL&chunkSize=5").to("mock:result");
             }
         });
         context.start();
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java
index cead95d..af9a338 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java
@@ -125,11 +125,11 @@ public class HdfsProducerSplitTest extends HdfsTestSupport {
         return new RouteBuilder() {
             @Override
             public void configure() throws Exception {
-                from("direct:start1").to("hdfs2:localhost/" + BASE_FILE.toUri() + "1?fileSystemType=LOCAL&splitStrategy=MESSAGES:1");
-                from("direct:start2").to("hdfs2:localhost/" + BASE_FILE.toUri() + "2?fileSystemType=LOCAL&splitStrategy=BYTES:5");
-                from("direct:start3").to("hdfs2:localhost/" + BASE_FILE.toUri() + "3?fileSystemType=LOCAL&splitStrategy=IDLE:1000");
-                from("direct:start4").to("hdfs2:localhost/" + BASE_FILE.toUri() + "4?fileSystemType=LOCAL&splitStrategy=IDLE:1000,MESSAGES:1");
-                from("direct:start5").to("hdfs2:localhost/" + BASE_FILE.toUri() + "5?fileSystemType=LOCAL&splitStrategy=IDLE:1000,BYTES:5");
+                from("direct:start1").to("hdfs:localhost/" + BASE_FILE.toUri() + "1?fileSystemType=LOCAL&splitStrategy=MESSAGES:1");
+                from("direct:start2").to("hdfs:localhost/" + BASE_FILE.toUri() + "2?fileSystemType=LOCAL&splitStrategy=BYTES:5");
+                from("direct:start3").to("hdfs:localhost/" + BASE_FILE.toUri() + "3?fileSystemType=LOCAL&splitStrategy=IDLE:1000");
+                from("direct:start4").to("hdfs:localhost/" + BASE_FILE.toUri() + "4?fileSystemType=LOCAL&splitStrategy=IDLE:1000,MESSAGES:1");
+                from("direct:start5").to("hdfs:localhost/" + BASE_FILE.toUri() + "5?fileSystemType=LOCAL&splitStrategy=IDLE:1000,BYTES:5");
             }
         };
     }
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java
index 95d52ed..c6814c3 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java
@@ -390,35 +390,35 @@ public class HdfsProducerTest extends HdfsTestSupport {
 
             @Override
             public void configure() throws Exception {
-                from("direct:start1").to("hdfs2://localhost/" + TEMP_DIR.toUri() + "/test-camel1?fileSystemType=LOCAL&valueType=TEXT&fileType=SEQUENCE_FILE");
+                from("direct:start1").to("hdfs://localhost/" + TEMP_DIR.toUri() + "/test-camel1?fileSystemType=LOCAL&valueType=TEXT&fileType=SEQUENCE_FILE");
 
                 /* For testing writables */
-                from("direct:write_boolean").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-boolean?fileSystemType=LOCAL&valueType=BOOLEAN&fileType=SEQUENCE_FILE");
+                from("direct:write_boolean").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-boolean?fileSystemType=LOCAL&valueType=BOOLEAN&fileType=SEQUENCE_FILE");
 
-                from("direct:write_byte").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-byte?fileSystemType=LOCAL&valueType=BYTE&fileType=SEQUENCE_FILE");
+                from("direct:write_byte").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-byte?fileSystemType=LOCAL&valueType=BYTE&fileType=SEQUENCE_FILE");
 
-                from("direct:write_int").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-int?fileSystemType=LOCAL&valueType=INT&fileType=SEQUENCE_FILE");
+                from("direct:write_int").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-int?fileSystemType=LOCAL&valueType=INT&fileType=SEQUENCE_FILE");
 
-                from("direct:write_float").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-float?fileSystemType=LOCAL&valueType=FLOAT&fileType=SEQUENCE_FILE");
+                from("direct:write_float").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-float?fileSystemType=LOCAL&valueType=FLOAT&fileType=SEQUENCE_FILE");
 
-                from("direct:write_long").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-long?fileSystemType=LOCAL&valueType=LONG&fileType=SEQUENCE_FILE");
+                from("direct:write_long").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-long?fileSystemType=LOCAL&valueType=LONG&fileType=SEQUENCE_FILE");
 
-                from("direct:write_double").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-double?fileSystemType=LOCAL&valueType=DOUBLE&fileType=SEQUENCE_FILE");
+                from("direct:write_double").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-double?fileSystemType=LOCAL&valueType=DOUBLE&fileType=SEQUENCE_FILE");
 
-                from("direct:write_text1").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-text1?fileSystemType=LOCAL&valueType=TEXT&fileType=SEQUENCE_FILE");
+                from("direct:write_text1").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-text1?fileSystemType=LOCAL&valueType=TEXT&fileType=SEQUENCE_FILE");
 
                 /* For testing key and value writing */
-                from("direct:write_text2").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-text2?fileSystemType=LOCAL&keyType=TEXT&valueType=TEXT&fileType=SEQUENCE_FILE");
+                from("direct:write_text2").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-text2?fileSystemType=LOCAL&keyType=TEXT&valueType=TEXT&fileType=SEQUENCE_FILE");
 
-                from("direct:write_text3").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-text3?fileSystemType=LOCAL&keyType=TEXT&valueType=TEXT&fileType=MAP_FILE");
+                from("direct:write_text3").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-text3?fileSystemType=LOCAL&keyType=TEXT&valueType=TEXT&fileType=MAP_FILE");
 
                 /* For testing ArrayFile */
-                from("direct:write_text4").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-text4?fileSystemType=LOCAL&valueType=TEXT&fileType=ARRAY_FILE");
+                from("direct:write_text4").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-text4?fileSystemType=LOCAL&valueType=TEXT&fileType=ARRAY_FILE");
 
                 /* For testing BloomMapFile */
-                from("direct:write_text5").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-text5?fileSystemType=LOCAL&keyType=TEXT&valueType=TEXT&fileType=BLOOMMAP_FILE");
+                from("direct:write_text5").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-text5?fileSystemType=LOCAL&keyType=TEXT&valueType=TEXT&fileType=BLOOMMAP_FILE");
 
-                from("direct:write_dynamic_filename").to("hdfs2:localhost/" + TEMP_DIR.toUri() + "/test-camel-dynamic/?fileSystemType=LOCAL&valueType=TEXT");
+                from("direct:write_dynamic_filename").to("hdfs:localhost/" + TEMP_DIR.toUri() + "/test-camel-dynamic/?fileSystemType=LOCAL&valueType=TEXT");
             }
         };
     }
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java
index 7e242c2..300416a 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java
@@ -61,7 +61,7 @@ public class HdfsAppendTest extends CamelTestSupport {
         context.addRoutes(new RouteBuilder() {
             @Override
             public void configure() throws Exception {
-                from("direct:start1").to("hdfs2://localhost:9000/tmp/test/test-camel-simple-write-file1?append=true&fileSystemType=HDFS");
+                from("direct:start1").to("hdfs://localhost:9000/tmp/test/test-camel-simple-write-file1?append=true&fileSystemType=HDFS");
             }
         });
         startCamelContext();
@@ -91,17 +91,17 @@ public class HdfsAppendTest extends CamelTestSupport {
         context.addRoutes(new RouteBuilder() {
             @Override
             public void configure() throws Exception {
-                from("direct:start1").to("hdfs2://localhost:9000/tmp/test-dynamic/?append=true&fileSystemType=HDFS");
+                from("direct:start1").to("hdfs://localhost:9000/tmp/test-dynamic/?append=true&fileSystemType=HDFS");
             }
         });
         startCamelContext();
 
         for (int i = 0; i < ITERATIONS; ++i) {
-            template.sendBodyAndHeader("direct:start1", "HELLO", Exchange.FILE_NAME, "camel-hdfs2.log");
+            template.sendBodyAndHeader("direct:start1", "HELLO", Exchange.FILE_NAME, "camel-hdfs.log");
         }
 
         Configuration conf = new Configuration();
-        Path file = new Path("hdfs://localhost:9000/tmp/test-dynamic/camel-hdfs2.log");
+        Path file = new Path("hdfs://localhost:9000/tmp/test-dynamic/camel-hdfs.log");
         FileSystem fs = FileSystem.get(file.toUri(), conf);
         FSDataInputStream in = fs.open(file);
         byte[] buffer = new byte[5];
diff --git a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java
index d7db231..4356ec3 100644
--- a/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java
+++ b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java
@@ -52,8 +52,8 @@ public class HdfsProducerConsumerIntegrationTest extends CamelTestSupport {
         context.addRoutes(new RouteBuilder() {
             @Override
             public void configure() {
-                from("direct:start").to("hdfs2://localhost:9000/tmp/test/test-camel-simple-write-file?fileSystemType=HDFS&splitStrategy=BYTES:5,IDLE:1000");
-                from("hdfs2://localhost:9000/tmp/test/test-camel-simple-write-file?pattern=*&initialDelay=2000&fileSystemType=HDFS&chunkSize=5").to("mock:result");
+                from("direct:start").to("hdfs://localhost:9000/tmp/test/test-camel-simple-write-file?fileSystemType=HDFS&splitStrategy=BYTES:5,IDLE:1000");
+                from("hdfs://localhost:9000/tmp/test/test-camel-simple-write-file?pattern=*&initialDelay=2000&fileSystemType=HDFS&chunkSize=5").to("mock:result");
             }
         });
         context.start();
@@ -107,10 +107,10 @@ public class HdfsProducerConsumerIntegrationTest extends CamelTestSupport {
             @Override
             public void configure() {
                 // difference in chunkSize only to allow multiple consumers
-                from("hdfs2://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=128").to("mock:result");
-                from("hdfs2://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=256").to("mock:result");
-                from("hdfs2://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=512").to("mock:result");
-                from("hdfs2://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=1024").to("mock:result");
+                from("hdfs://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=128").to("mock:result");
+                from("hdfs://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=256").to("mock:result");
+                from("hdfs://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=512").to("mock:result");
+                from("hdfs://localhost:9000/tmp/test/multiple-consumers?pattern=*.txt&fileSystemType=HDFS&chunkSize=1024").to("mock:result");
             }
         });
         context.start();
diff --git a/components/camel-hdfs/src/test/resources/log4j2.properties b/components/camel-hdfs/src/test/resources/log4j2.properties
index bc0c8a1..76695b7 100644
--- a/components/camel-hdfs/src/test/resources/log4j2.properties
+++ b/components/camel-hdfs/src/test/resources/log4j2.properties
@@ -17,7 +17,7 @@
 
 appender.file.type = File
 appender.file.name = file
-appender.file.fileName = target/camel-hdfs2-test.log
+appender.file.fileName = target/camel-hdfs-test.log
 appender.file.layout.type = PatternLayout
 appender.file.layout.pattern = %d [%-15.15t] %-5p %-30.30c{1} - %m%n
 appender.out.type = Console
diff --git a/components/pom.xml b/components/pom.xml
index 8231abe..b6c2da4 100644
--- a/components/pom.xml
+++ b/components/pom.xml
@@ -186,7 +186,7 @@
         <module>camel-guava-eventbus</module>
         <module>camel-hazelcast</module>
         <module>camel-hbase</module>
-        <module>camel-hdfs2</module>
+        <module>camel-hdfs</module>
         <module>camel-hipchat</module>
         <module>camel-hl7</module>
         <module>camel-ical</module>
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
index 7439d3c..95b894c 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
@@ -39,7 +39,7 @@ public interface HdfsEndpointBuilderFactory {
 
 
     /**
-     * Builder for endpoint consumers for the HDFS2 component.
+     * Builder for endpoint consumers for the HDFS component.
      */
     public interface HdfsEndpointConsumerBuilder
             extends
@@ -617,7 +617,7 @@ public interface HdfsEndpointBuilderFactory {
     }
 
     /**
-     * Advanced builder for endpoint consumers for the HDFS2 component.
+     * Advanced builder for endpoint consumers for the HDFS component.
      */
     public interface AdvancedHdfsEndpointConsumerBuilder
             extends
@@ -991,7 +991,7 @@ public interface HdfsEndpointBuilderFactory {
     }
 
     /**
-     * Builder for endpoint producers for the HDFS2 component.
+     * Builder for endpoint producers for the HDFS component.
      */
     public interface HdfsEndpointProducerBuilder
             extends
@@ -1235,7 +1235,7 @@ public interface HdfsEndpointBuilderFactory {
     }
 
     /**
-     * Advanced builder for endpoint producers for the HDFS2 component.
+     * Advanced builder for endpoint producers for the HDFS component.
      */
     public interface AdvancedHdfsEndpointProducerBuilder
             extends
@@ -1520,7 +1520,7 @@ public interface HdfsEndpointBuilderFactory {
     }
 
     /**
-     * Builder for endpoint for the HDFS2 component.
+     * Builder for endpoint for the HDFS component.
      */
     public interface HdfsEndpointBuilder
             extends
@@ -1676,7 +1676,7 @@ public interface HdfsEndpointBuilderFactory {
     }
 
     /**
-     * Advanced builder for endpoint for the HDFS2 component.
+     * Advanced builder for endpoint for the HDFS component.
      */
     public interface AdvancedHdfsEndpointBuilder
             extends
@@ -2011,7 +2011,7 @@ public interface HdfsEndpointBuilderFactory {
         BLOCK;
     }
     /**
-     * HDFS2 (camel-hdfs)
+     * HDFS (camel-hdfs)
      * For reading/writing from/to an HDFS filesystem using Hadoop 2.x.
      * 
      * Category: hadoop,file
diff --git a/parent/pom.xml b/parent/pom.xml
index 38cc3ff..9bb17eb 100644
--- a/parent/pom.xml
+++ b/parent/pom.xml
@@ -1389,7 +1389,7 @@
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
-        <artifactId>camel-hdfs2</artifactId>
+        <artifactId>camel-hdfs</artifactId>
         <version>${project.version}</version>
       </dependency>
       <dependency>
@@ -2933,7 +2933,7 @@
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
-        <artifactId>camel-hdfs2-starter</artifactId>
+        <artifactId>camel-hdfs-starter</artifactId>
         <version>${project.version}</version>
       </dependency>
       <dependency>
diff --git a/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
index 34c1f3e..829973c 100644
--- a/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
@@ -75,7 +75,7 @@ public class HdfsComponentAutoConfiguration {
     }
 
     @Lazy
-    @Bean({"hdfs-component", "hdfs2-component"})
+    @Bean(name = "hdfs-component")
     @ConditionalOnMissingBean(HdfsComponent.class)
     public HdfsComponent configureHdfsComponent() throws Exception {
         HdfsComponent component = new HdfsComponent();
diff --git a/platforms/spring-boot/components-starter/pom.xml b/platforms/spring-boot/components-starter/pom.xml
index 3ffdd06..e4887f7 100644
--- a/platforms/spring-boot/components-starter/pom.xml
+++ b/platforms/spring-boot/components-starter/pom.xml
@@ -210,7 +210,6 @@
     <module>camel-hazelcast-starter</module>
     <module>camel-hbase-starter</module>
     <module>camel-hdfs-starter</module>
-    <module>camel-hdfs2-starter</module>
     <module>camel-hipchat-starter</module>
     <module>camel-hl7-starter</module>
     <module>camel-http-common-starter</module>


[camel] 04/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Updated docs link and regen

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit e8d59b81697381f3a599841e555627a42ea1066d
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 11:29:28 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Updated docs link and regen
---
 .../camel-hdfs/src/main/docs/hdfs-component.adoc   | 10 +++----
 components/readme.adoc                             |  4 +--
 docs/components/modules/ROOT/nav.adoc              |  2 +-
 .../{hdfs2-component.adoc => hdfs-component.adoc}  | 32 +++++++++++-----------
 docs/user-manual/modules/ROOT/pages/index.adoc     |  2 +-
 .../camel-spring-boot-dependencies/pom.xml         | 10 +++----
 6 files changed, 30 insertions(+), 30 deletions(-)

diff --git a/components/camel-hdfs/src/main/docs/hdfs-component.adoc b/components/camel-hdfs/src/main/docs/hdfs-component.adoc
index 1d222ea..d6c1721 100644
--- a/components/camel-hdfs/src/main/docs/hdfs-component.adoc
+++ b/components/camel-hdfs/src/main/docs/hdfs-component.adoc
@@ -150,7 +150,7 @@ When using Spring Boot make sure to use the following Maven dependency to have s
 ----
 <dependency>
   <groupId>org.apache.camel</groupId>
-  <artifactId>camel-hdfs2-starter</artifactId>
+  <artifactId>camel-hdfs-starter</artifactId>
   <version>x.x.x</version>
   <!-- use the same version as your Camel core version -->
 </dependency>
@@ -164,10 +164,10 @@ The component supports 4 options, which are listed below.
 [width="100%",cols="2,5,^1,2",options="header"]
 |===
 | Name | Description | Default | Type
-| *camel.component.hdfs2.basic-property-binding* | Whether the component should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities | false | Boolean
-| *camel.component.hdfs2.enabled* | Enable hdfs2 component | true | Boolean
-| *camel.component.hdfs2.j-a-a-s-configuration* | To use the given configuration for security with JAAS. The option is a javax.security.auth.login.Configuration type. |  | String
-| *camel.component.hdfs2.resolve-property-placeholders* | Whether the component should resolve property placeholders on itself when starting. Only properties which are of String type can use property placeholders. | true | Boolean
+| *camel.component.hdfs.basic-property-binding* | Whether the component should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities | false | Boolean
+| *camel.component.hdfs.enabled* | Whether to enable auto configuration of the hdfs component. This is enabled by default. |  | Boolean
+| *camel.component.hdfs.j-a-a-s-configuration* | To use the given configuration for security with JAAS. The option is a javax.security.auth.login.Configuration type. |  | String
+| *camel.component.hdfs.resolve-property-placeholders* | Whether the component should resolve property placeholders on itself when starting. Only properties which are of String type can use property placeholders. | true | Boolean
 |===
 // spring-boot-auto-configure options: END
 
diff --git a/components/readme.adoc b/components/readme.adoc
index d857c24..442597a 100644
--- a/components/readme.adoc
+++ b/components/readme.adoc
@@ -376,8 +376,8 @@ Number of Components: 297 in 234 JAR artifacts (0 deprecated)
 | link:camel-hbase/src/main/docs/hbase-component.adoc[HBase] (camel-hbase) +
 `hbase:tableName` | 2.10 | For reading/writing from/to an HBase store (Hadoop database).
 
-| link:camel-hdfs2/src/main/docs/hdfs2-component.adoc[HDFS2] (camel-hdfs2) +
-`hdfs2:hostName:port/path` | 2.14 | For reading/writing from/to an HDFS filesystem using Hadoop 2.x.
+| link:camel-hdfs/src/main/docs/hdfs-component.adoc[HDFS] (camel-hdfs) +
+`hdfs:hostName:port/path` | 2.14 | For reading/writing from/to an HDFS filesystem using Hadoop 2.x.
 
 | link:camel-hipchat/src/main/docs/hipchat-component.adoc[Hipchat] (camel-hipchat) +
 `hipchat:protocol:host:port` | 2.15 | The hipchat component supports producing and consuming messages from/to Hipchat service.
diff --git a/docs/components/modules/ROOT/nav.adoc b/docs/components/modules/ROOT/nav.adoc
index eaf1bea..c602e3c 100644
--- a/docs/components/modules/ROOT/nav.adoc
+++ b/docs/components/modules/ROOT/nav.adoc
@@ -148,7 +148,7 @@
 * xref:hazelcast-topic-component.adoc[Hazelcast Topic Component]
 * xref:hazelcast.adoc[Hazelcast Component]
 * xref:hbase-component.adoc[HBase Component]
-* xref:hdfs2-component.adoc[HDFS2 Component]
+* xref:hdfs-component.adoc[HDFS Component]
 * xref:hipchat-component.adoc[Hipchat Component]
 * xref:hl7-dataformat.adoc[HL7 DataFormat]
 * xref:hl7terser-language.adoc[HL7 Terser Language]
diff --git a/docs/components/modules/ROOT/pages/hdfs2-component.adoc b/docs/components/modules/ROOT/pages/hdfs-component.adoc
similarity index 92%
rename from docs/components/modules/ROOT/pages/hdfs2-component.adoc
rename to docs/components/modules/ROOT/pages/hdfs-component.adoc
index f42ba0e..d6c1721 100644
--- a/docs/components/modules/ROOT/pages/hdfs2-component.adoc
+++ b/docs/components/modules/ROOT/pages/hdfs-component.adoc
@@ -1,9 +1,9 @@
-[[hdfs2-component]]
-= HDFS2 Component
+[[hdfs-component]]
+= HDFS Component
 
 *Available as of Camel version 2.14*
 
-The HDFS2 component enables you to read and write messages from/to an
+The HDFS component enables you to read and write messages from/to an
 HDFS file system using Hadoop 2.x. HDFS is the distributed file system
 at the heart of http://hadoop.apache.org[Hadoop].
 
@@ -14,7 +14,7 @@ for this component:
 ------------------------------------------------------------
 <dependency>
     <groupId>org.apache.camel</groupId>
-    <artifactId>camel-hdfs2</artifactId>
+    <artifactId>camel-hdfs</artifactId>
     <version>x.x.x</version>
     <!-- use the same version as your Camel core version -->
 </dependency>
@@ -24,7 +24,7 @@ for this component:
 
 [source,java]
 ----------------------------------------
-hdfs2://hostname[:port][/path][?options]
+hdfs://hostname[:port][/path][?options]
 ----------------------------------------
 
 You can append query options to the URI in the following format,
@@ -41,7 +41,7 @@ a different file per split named using the configured
 UuidGenerator.
 
 
-When consuming from hdfs2 then in normal mode, a file is split into
+When consuming from hdfs then in normal mode, a file is split into
 chunks, producing a message per chunk. You can configure the size of the
 chunk using the chunkSize option. If you want to read from hdfs and
 write to a regular file using the file component, then you can use the
@@ -54,7 +54,7 @@ fileMode=Append to append each of the chunks together.
 
 
 // component options: START
-The HDFS2 component supports 3 options, which are listed below.
+The HDFS component supports 3 options, which are listed below.
 
 
 
@@ -73,10 +73,10 @@ The HDFS2 component supports 3 options, which are listed below.
 
 
 // endpoint options: START
-The HDFS2 endpoint is configured using URI syntax:
+The HDFS endpoint is configured using URI syntax:
 
 ----
-hdfs2:hostName:port/path
+hdfs:hostName:port/path
 ----
 
 with the following path and query parameters:
@@ -150,7 +150,7 @@ When using Spring Boot make sure to use the following Maven dependency to have s
 ----
 <dependency>
   <groupId>org.apache.camel</groupId>
-  <artifactId>camel-hdfs2-starter</artifactId>
+  <artifactId>camel-hdfs-starter</artifactId>
   <version>x.x.x</version>
   <!-- use the same version as your Camel core version -->
 </dependency>
@@ -164,10 +164,10 @@ The component supports 4 options, which are listed below.
 [width="100%",cols="2,5,^1,2",options="header"]
 |===
 | Name | Description | Default | Type
-| *camel.component.hdfs2.basic-property-binding* | Whether the component should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities | false | Boolean
-| *camel.component.hdfs2.enabled* | Enable hdfs2 component | true | Boolean
-| *camel.component.hdfs2.j-a-a-s-configuration* | To use the given configuration for security with JAAS. The option is a javax.security.auth.login.Configuration type. |  | String
-| *camel.component.hdfs2.resolve-property-placeholders* | Whether the component should resolve property placeholders on itself when starting. Only properties which are of String type can use property placeholders. | true | Boolean
+| *camel.component.hdfs.basic-property-binding* | Whether the component should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities | false | Boolean
+| *camel.component.hdfs.enabled* | Whether to enable auto configuration of the hdfs component. This is enabled by default. |  | Boolean
+| *camel.component.hdfs.j-a-a-s-configuration* | To use the given configuration for security with JAAS. The option is a javax.security.auth.login.Configuration type. |  | String
+| *camel.component.hdfs.resolve-property-placeholders* | Whether the component should resolve property placeholders on itself when starting. Only properties which are of String type can use property placeholders. | true | Boolean
 |===
 // spring-boot-auto-configure options: END
 
@@ -223,7 +223,7 @@ for example:
 
 [source,java]
 -----------------------------------------------------------------
-hdfs2://localhost/tmp/simple-file?splitStrategy=IDLE:1000,BYTES:5
+hdfs://localhost/tmp/simple-file?splitStrategy=IDLE:1000,BYTES:5
 -----------------------------------------------------------------
 
 it means: a new file is created either when it has been idle for more
@@ -249,7 +249,7 @@ split strategy.
 
 == Controlling to close file stream
 
-When using the xref:hdfs2-component.adoc[HDFS2] producer *without* a split
+When using the xref:hdfs-component.adoc[HDFS] producer *without* a split
 strategy, then the file output stream is by default closed after the
 write. However you may want to keep the stream open, and only explicitly
 close the stream later. For that you can use the header
diff --git a/docs/user-manual/modules/ROOT/pages/index.adoc b/docs/user-manual/modules/ROOT/pages/index.adoc
index b9905c0..353487e 100644
--- a/docs/user-manual/modules/ROOT/pages/index.adoc
+++ b/docs/user-manual/modules/ROOT/pages/index.adoc
@@ -274,7 +274,7 @@ camel routes without them knowing
 ** xref:components::hazelcast-set-component.adoc[Hazelcast Set]
 ** xref:components::hazelcast-topic-component.adoc[Hazelcast Topic]
 ** xref:components::hbase-component.adoc[HBase]
-** xref:components::hdfs2-component.adoc[HDFS2]
+** xref:components::hdfs-component.adoc[HDFS]
 ** xref:components::hipchat-component.adoc[Hipchat]
 ** xref:components::http-component.adoc[HTTP]
 ** xref:components::iec60870-client-component.adoc[IEC 60870 Client]
diff --git a/platforms/spring-boot/spring-boot-dm/camel-spring-boot-dependencies/pom.xml b/platforms/spring-boot/spring-boot-dm/camel-spring-boot-dependencies/pom.xml
index c1281f8..d3e7368 100644
--- a/platforms/spring-boot/spring-boot-dm/camel-spring-boot-dependencies/pom.xml
+++ b/platforms/spring-boot/spring-boot-dm/camel-spring-boot-dependencies/pom.xml
@@ -213,7 +213,7 @@
       <dependency>
         <groupId>net.sf.saxon</groupId>
         <artifactId>Saxon-HE</artifactId>
-        <version>9.9.1-3</version>
+        <version>9.9.1-4</version>
       </dependency>
       <dependency>
         <groupId>ognl</groupId>
@@ -1469,12 +1469,12 @@
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
-        <artifactId>camel-hdfs2</artifactId>
+        <artifactId>camel-hdfs</artifactId>
         <version>${project.version}</version>
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
-        <artifactId>camel-hdfs2-starter</artifactId>
+        <artifactId>camel-hdfs-starter</artifactId>
         <version>${project.version}</version>
       </dependency>
       <dependency>
@@ -3661,12 +3661,12 @@
       <dependency>
         <groupId>org.apache.pulsar</groupId>
         <artifactId>pulsar-client</artifactId>
-        <version>2.3.2</version>
+        <version>2.4.0</version>
       </dependency>
       <dependency>
         <groupId>org.apache.pulsar</groupId>
         <artifactId>pulsar-client-admin</artifactId>
-        <version>2.3.2</version>
+        <version>2.4.0</version>
       </dependency>
       <dependency>
         <groupId>org.apache.ws.commons.axiom</groupId>


[camel] 05/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Karaf integration test and feature updated

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 2fb55903b4ce1f40c44ee86cc7cf6a4f51edb41d
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 11:38:29 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Karaf integration test and feature updated
---
 platforms/karaf/features/src/main/resources/features.xml            | 6 +++---
 .../camel/itest/karaf/{CamelHdfs2Test.java => CamelHdfsTest.java}   | 6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/platforms/karaf/features/src/main/resources/features.xml b/platforms/karaf/features/src/main/resources/features.xml
index c87f8af..6a4b85b 100644
--- a/platforms/karaf/features/src/main/resources/features.xml
+++ b/platforms/karaf/features/src/main/resources/features.xml
@@ -1202,8 +1202,8 @@
     <bundle dependency='true'>mvn:com.hazelcast/hazelcast-client/${hazelcast-version}</bundle>
     <bundle>mvn:org.apache.camel/camel-hazelcast/${project.version}</bundle>
   </feature>
-  <feature name='camel-hdfs2' version='${project.version}' start-level='50'>
-    <details>The camel-hdfs2 feature can only run if you have libsnappyjava.dylib in java.library.path</details>
+  <feature name='camel-hdfs' version='${project.version}' start-level='50'>
+    <details>The camel-hdfs feature can only run if you have libsnappyjava.dylib in java.library.path</details>
     <feature version='${project.version}'>camel-core</feature>
     <bundle dependency='true'>mvn:commons-lang/commons-lang/${commons-lang-version}</bundle>
     <bundle dependency='true'>mvn:com.google.guava/guava/${google-guava-version}</bundle>
@@ -1233,7 +1233,7 @@
     <bundle dependency='true'>mvn:org.apache.servicemix.bundles/org.apache.servicemix.bundles.xmlresolver/${xmlresolver-bundle-version}</bundle>
     <bundle dependency='true'>mvn:org.apache.servicemix.specs/org.apache.servicemix.specs.jsr311-api-1.1.1/${servicemix-specs-version}</bundle>
     <bundle dependency='true'>wrap:mvn:org.apache.htrace/htrace-core/${htrace-version}$Bundle-SymbolicName=Apache-HTrace-Core</bundle>
-    <bundle>mvn:org.apache.camel/camel-hdfs2/${project.version}</bundle>
+    <bundle>mvn:org.apache.camel/camel-hdfs/${project.version}</bundle>
     <bundle>mvn:org.apache.servicemix.bundles/org.apache.servicemix.bundles.hadoop-client/${hadoop2-bundle-version}</bundle>
   </feature>
   <feature name='camel-headersmap' version='${project.version}' start-level='50'>
diff --git a/tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/CamelHdfs2Test.java b/tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/CamelHdfsTest.java
similarity index 94%
rename from tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/CamelHdfs2Test.java
rename to tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/CamelHdfsTest.java
index 0ab2900..8edfc56 100644
--- a/tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/CamelHdfs2Test.java
+++ b/tests/camel-itest-karaf/src/test/java/org/apache/camel/itest/karaf/CamelHdfsTest.java
@@ -21,13 +21,13 @@ import org.junit.runner.RunWith;
 import org.ops4j.pax.exam.junit.PaxExam;
 
 @RunWith(PaxExam.class)
-public class CamelHdfs2Test extends BaseKarafTest {
+public class CamelHdfsTest extends BaseKarafTest {
 
-    public static final String COMPONENT = extractName(CamelHdfs2Test.class);
+    public static final String COMPONENT = extractName(CamelHdfsTest.class);
 
     @Test
     public void test() throws Exception {
         testComponent(COMPONENT);
     }
 
-}
\ No newline at end of file
+}


[camel] 07/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Removed references in comments

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 81cfdb0ebf4fcd391d84275b513fc49beda95478
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 11:41:38 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Removed references in comments
---
 .../src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java  | 2 +-
 parent/pom.xml                                                          | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java
index 15f4e4a..81a57da 100644
--- a/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java
+++ b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java
@@ -38,7 +38,7 @@ public class HdfsOsgiHelper {
      */
     public HdfsOsgiHelper(Map<String, String> fileSystems) {
         try {
-            // get bundle classloader for camel-hdfs2 bundle
+            // get bundle classloader for camel-hdfs bundle
             ClassLoader cl = getClass().getClassLoader();
             Configuration conf = new Configuration();
             // set that as the hdfs configuration's classloader
diff --git a/parent/pom.xml b/parent/pom.xml
index 9bb17eb..08bacbf 100644
--- a/parent/pom.xml
+++ b/parent/pom.xml
@@ -80,7 +80,7 @@
         <avro-version>1.9.0</avro-version>
         <avro-ipc-jetty-version>1.9.0</avro-ipc-jetty-version>
         <avro-ipc-netty-version>1.9.0</avro-ipc-netty-version>
-        <!-- these two avro bundles relates to camel-hdfs2 karaf feature -->
+        <!-- these two avro bundles relates to camel-hdfs karaf feature -->
         <avro-bundle-version>1.8.2_1</avro-bundle-version>
         <awaitility-version>3.1.6</awaitility-version>
         <aws-java-sdk-bundle-version>1.11.595_1</aws-java-sdk-bundle-version>


[camel] 01/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit a25c0c8093aa954e9b2de2cd43af46b3d3d439ad
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 10:28:36 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs
---
 components/{camel-hdfs2 => camel-hdfs}/pom.xml                 |  4 ++--
 .../src/main/docs/hdfs2-component.adoc                         |  0
 .../java/org/apache/camel/component/hdfs2/HdfsComponent.java   |  0
 .../org/apache/camel/component/hdfs2/HdfsCompressionCodec.java |  0
 .../org/apache/camel/component/hdfs2/HdfsConfiguration.java    |  0
 .../java/org/apache/camel/component/hdfs2/HdfsConstants.java   |  0
 .../java/org/apache/camel/component/hdfs2/HdfsConsumer.java    |  0
 .../java/org/apache/camel/component/hdfs2/HdfsEndpoint.java    |  0
 .../org/apache/camel/component/hdfs2/HdfsFileSystemType.java   |  0
 .../java/org/apache/camel/component/hdfs2/HdfsFileType.java    |  0
 .../main/java/org/apache/camel/component/hdfs2/HdfsHeader.java |  0
 .../main/java/org/apache/camel/component/hdfs2/HdfsInfo.java   |  0
 .../java/org/apache/camel/component/hdfs2/HdfsInfoFactory.java |  0
 .../java/org/apache/camel/component/hdfs2/HdfsInputStream.java |  0
 .../java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java  |  0
 .../org/apache/camel/component/hdfs2/HdfsOutputStream.java     |  0
 .../java/org/apache/camel/component/hdfs2/HdfsProducer.java    |  0
 .../apache/camel/component/hdfs2/HdfsWritableFactories.java    |  0
 .../src/main/java/org/apache/camel/component/hdfs2/Holder.java |  0
 .../java/org/apache/camel/component/hdfs2/WritableType.java    |  0
 .../org/apache/camel/component/hdfs2/osgi/HdfsActivator.java   |  0
 .../org/apache/camel/component/hdfs2/FromFileToHdfsTest.java   |  0
 .../org/apache/camel/component/hdfs2/HdfsConsumerTest.java     |  0
 .../apache/camel/component/hdfs2/HdfsProducerConsumerTest.java |  0
 .../apache/camel/component/hdfs2/HdfsProducerSplitTest.java    |  0
 .../org/apache/camel/component/hdfs2/HdfsProducerTest.java     |  0
 .../java/org/apache/camel/component/hdfs2/HdfsTestSupport.java |  0
 .../camel/component/hdfs2/integration/HdfsAppendTest.java      |  0
 .../hdfs2/integration/HdfsProducerConsumerIntegrationTest.java |  0
 .../src/test/resources/hdfs-default.xml                        |  0
 .../src/test/resources/hdfs-test.xml                           |  0
 .../src/test/resources/log4j2.properties                       |  0
 .../camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java |  4 ++--
 .../{camel-hdfs2-starter => camel-hdfs-starter}/pom.xml        |  6 +++---
 .../hdfs2/springboot/HdfsComponentAutoConfiguration.java       |  6 +++---
 .../component/hdfs2/springboot/HdfsComponentConfiguration.java |  4 ++--
 .../src/main/resources/META-INF/LICENSE.txt                    |  0
 .../src/main/resources/META-INF/NOTICE.txt                     |  0
 .../src/main/resources/META-INF/spring.factories               |  1 +
 .../src/main/resources/META-INF/spring.provides                |  2 +-
 .../META-INF/additional-spring-configuration-metadata.json     | 10 ----------
 platforms/spring-boot/components-starter/pom.xml               |  1 +
 42 files changed, 15 insertions(+), 23 deletions(-)

diff --git a/components/camel-hdfs2/pom.xml b/components/camel-hdfs/pom.xml
similarity index 98%
rename from components/camel-hdfs2/pom.xml
rename to components/camel-hdfs/pom.xml
index 4b47939..dab85d9 100644
--- a/components/camel-hdfs2/pom.xml
+++ b/components/camel-hdfs/pom.xml
@@ -27,9 +27,9 @@
         <version>3.0.0-SNAPSHOT</version>
     </parent>
 
-    <artifactId>camel-hdfs2</artifactId>
+    <artifactId>camel-hdfs</artifactId>
     <packaging>jar</packaging>
-    <name>Camel :: HDFS2</name>
+    <name>Camel :: HDFS</name>
     <description>Camel HDFS support with Hadoop 2.x libraries</description>
 
     <properties>
diff --git a/components/camel-hdfs2/src/main/docs/hdfs2-component.adoc b/components/camel-hdfs/src/main/docs/hdfs2-component.adoc
similarity index 100%
rename from components/camel-hdfs2/src/main/docs/hdfs2-component.adoc
rename to components/camel-hdfs/src/main/docs/hdfs2-component.adoc
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsComponent.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsCompressionCodec.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsCompressionCodec.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsCompressionCodec.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsCompressionCodec.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConfiguration.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsConstants.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConstants.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsConstants.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConstants.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsConsumer.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConsumer.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsConsumer.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsConsumer.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsEndpoint.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsFileSystemType.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsFileSystemType.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsFileSystemType.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsFileSystemType.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsFileType.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsFileType.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsFileType.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsFileType.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsHeader.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsHeader.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsHeader.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsHeader.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsInfo.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsInfo.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsInfo.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsInfo.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsInfoFactory.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsInfoFactory.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsInfoFactory.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsInfoFactory.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsInputStream.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsInputStream.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsInputStream.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsInputStream.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOsgiHelper.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsOutputStream.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOutputStream.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsOutputStream.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsOutputStream.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsProducer.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsProducer.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsProducer.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsProducer.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsWritableFactories.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsWritableFactories.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/HdfsWritableFactories.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/HdfsWritableFactories.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/Holder.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/Holder.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/Holder.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/Holder.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/WritableType.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/WritableType.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/WritableType.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/WritableType.java
diff --git a/components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/osgi/HdfsActivator.java b/components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/osgi/HdfsActivator.java
similarity index 100%
rename from components/camel-hdfs2/src/main/java/org/apache/camel/component/hdfs2/osgi/HdfsActivator.java
rename to components/camel-hdfs/src/main/java/org/apache/camel/component/hdfs2/osgi/HdfsActivator.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/FromFileToHdfsTest.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsConsumerTest.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerConsumerTest.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerSplitTest.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsProducerTest.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsTestSupport.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsTestSupport.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/HdfsTestSupport.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/HdfsTestSupport.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsAppendTest.java
diff --git a/components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java b/components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java
similarity index 100%
rename from components/camel-hdfs2/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java
rename to components/camel-hdfs/src/test/java/org/apache/camel/component/hdfs2/integration/HdfsProducerConsumerIntegrationTest.java
diff --git a/components/camel-hdfs2/src/test/resources/hdfs-default.xml b/components/camel-hdfs/src/test/resources/hdfs-default.xml
similarity index 100%
rename from components/camel-hdfs2/src/test/resources/hdfs-default.xml
rename to components/camel-hdfs/src/test/resources/hdfs-default.xml
diff --git a/components/camel-hdfs2/src/test/resources/hdfs-test.xml b/components/camel-hdfs/src/test/resources/hdfs-test.xml
similarity index 100%
rename from components/camel-hdfs2/src/test/resources/hdfs-test.xml
rename to components/camel-hdfs/src/test/resources/hdfs-test.xml
diff --git a/components/camel-hdfs2/src/test/resources/log4j2.properties b/components/camel-hdfs/src/test/resources/log4j2.properties
similarity index 100%
rename from components/camel-hdfs2/src/test/resources/log4j2.properties
rename to components/camel-hdfs/src/test/resources/log4j2.properties
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
index d298cda..7439d3c 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
@@ -2011,12 +2011,12 @@ public interface HdfsEndpointBuilderFactory {
         BLOCK;
     }
     /**
-     * HDFS2 (camel-hdfs2)
+     * HDFS2 (camel-hdfs)
      * For reading/writing from/to an HDFS filesystem using Hadoop 2.x.
      * 
      * Category: hadoop,file
      * Available as of version: 2.14
-     * Maven coordinates: org.apache.camel:camel-hdfs2
+     * Maven coordinates: org.apache.camel:camel-hdfs
      * 
      * Syntax: <code>hdfs:hostName:port/path</code>
      * 
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/pom.xml b/platforms/spring-boot/components-starter/camel-hdfs-starter/pom.xml
similarity index 94%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/pom.xml
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/pom.xml
index 2b47c41..1f75176 100644
--- a/platforms/spring-boot/components-starter/camel-hdfs2-starter/pom.xml
+++ b/platforms/spring-boot/components-starter/camel-hdfs-starter/pom.xml
@@ -24,9 +24,9 @@
     <artifactId>components-starter</artifactId>
     <version>3.0.0-SNAPSHOT</version>
   </parent>
-  <artifactId>camel-hdfs2-starter</artifactId>
+  <artifactId>camel-hdfs-starter</artifactId>
   <packaging>jar</packaging>
-  <name>Spring-Boot Starter :: Camel :: HDFS2</name>
+  <name>Spring-Boot Starter :: Camel :: HDFS</name>
   <description>Spring-Boot Starter for Camel HDFS support with Hadoop 2.x libraries</description>
   <dependencies>
     <dependency>
@@ -36,7 +36,7 @@
     </dependency>
     <dependency>
       <groupId>org.apache.camel</groupId>
-      <artifactId>camel-hdfs2</artifactId>
+      <artifactId>camel-hdfs</artifactId>
       <version>${project.version}</version>
       <!--START OF GENERATED CODE-->
       <exclusions>
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
similarity index 96%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
index f0522e3..34c1f3e 100644
--- a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentAutoConfiguration.java
@@ -70,7 +70,7 @@ public class HdfsComponentAutoConfiguration {
 
     static class GroupConditions extends GroupCondition {
         public GroupConditions() {
-            super("camel.component", "camel.component.hdfs2");
+            super("camel.component", "camel.component.hdfs");
         }
     }
 
@@ -110,12 +110,12 @@ public class HdfsComponentAutoConfiguration {
                         ? HierarchicalPropertiesEvaluator.evaluate(
                                 applicationContext.getEnvironment(),
                                 "camel.component.customizer",
-                                "camel.component.hdfs2.customizer",
+                                "camel.component.hdfs.customizer",
                                 ((HasId) customizer).getId())
                         : HierarchicalPropertiesEvaluator.evaluate(
                                 applicationContext.getEnvironment(),
                                 "camel.component.customizer",
-                                "camel.component.hdfs2.customizer");
+                                "camel.component.hdfs.customizer");
                 if (useCustomizer) {
                     LOGGER.debug("Configure component {}, with customizer {}",
                             component, customizer);
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/LICENSE.txt b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/LICENSE.txt
similarity index 100%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/LICENSE.txt
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/LICENSE.txt
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/NOTICE.txt b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/NOTICE.txt
similarity index 100%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/NOTICE.txt
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/NOTICE.txt
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/spring.factories b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/spring.factories
similarity index 99%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/spring.factories
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/spring.factories
index 98a0cb8..563bd32 100644
--- a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/spring.factories
+++ b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/spring.factories
@@ -14,5 +14,6 @@
 ## See the License for the specific language governing permissions and
 ## limitations under the License.
 ## ---------------------------------------------------------------------------
+
 org.springframework.boot.autoconfigure.EnableAutoConfiguration=\
 org.apache.camel.component.hdfs2.springboot.HdfsComponentAutoConfiguration
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/spring.provides b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/spring.provides
similarity index 97%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/spring.provides
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/spring.provides
index 18135c1..1f16658 100644
--- a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/spring.provides
+++ b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/resources/META-INF/spring.provides
@@ -14,4 +14,4 @@
 ## See the License for the specific language governing permissions and
 ## limitations under the License.
 ## ---------------------------------------------------------------------------
-provides: camel-hdfs2
+provides: camel-hdfs
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json b/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json
deleted file mode 100644
index 796fed7..0000000
--- a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json
+++ /dev/null
@@ -1,10 +0,0 @@
-{
-  "properties": [
-    {
-      "defaultValue": true,
-      "name": "camel.component.hdfs2.enabled",
-      "description": "Enable hdfs2 component",
-      "type": "java.lang.Boolean"
-    }
-  ]
-}
\ No newline at end of file
diff --git a/platforms/spring-boot/components-starter/pom.xml b/platforms/spring-boot/components-starter/pom.xml
index c5cdd9a..3ffdd06 100644
--- a/platforms/spring-boot/components-starter/pom.xml
+++ b/platforms/spring-boot/components-starter/pom.xml
@@ -209,6 +209,7 @@
     <module>camel-guava-eventbus-starter</module>
     <module>camel-hazelcast-starter</module>
     <module>camel-hbase-starter</module>
+    <module>camel-hdfs-starter</module>
     <module>camel-hdfs2-starter</module>
     <module>camel-hipchat-starter</module>
     <module>camel-hl7-starter</module>


[camel] 06/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - SB integration test updated

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit b334321081245eff06cde3ec56cdebf782de5125
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 11:40:33 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - SB integration test updated
---
 .../itest/springboot/{CamelHdfs2Test.java => CamelHdfsTest.java}      | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelHdfs2Test.java b/tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelHdfsTest.java
similarity index 92%
rename from tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelHdfs2Test.java
rename to tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelHdfsTest.java
index 4f7a0b3..7fb9031 100644
--- a/tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelHdfs2Test.java
+++ b/tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelHdfsTest.java
@@ -25,7 +25,7 @@ import org.junit.runner.RunWith;
 
 
 @RunWith(Arquillian.class)
-public class CamelHdfs2Test extends AbstractSpringBootTestSupport {
+public class CamelHdfsTest extends AbstractSpringBootTestSupport {
 
     @Deployment
     public static Archive<?> createSpringBootPackage() throws Exception {
@@ -34,7 +34,7 @@ public class CamelHdfs2Test extends AbstractSpringBootTestSupport {
 
     public static ITestConfig createTestConfig() {
         return new ITestConfigBuilder()
-                .module(inferModuleName(CamelHdfs2Test.class))
+                .module(inferModuleName(CamelHdfsTest.class))
                 .build();
     }
 


[camel] 03/07: CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Updated docs

Posted by ac...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 44ba6e31e4f962a40a35086093c9cffa6e7806b6
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Aug 5 10:40:18 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-hdfs2 to camel-hdfs - Updated docs
---
 components/camel-hdfs/src/main/docs/hdfs-component.adoc | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/components/camel-hdfs/src/main/docs/hdfs-component.adoc b/components/camel-hdfs/src/main/docs/hdfs-component.adoc
index b8880ef..1d222ea 100644
--- a/components/camel-hdfs/src/main/docs/hdfs-component.adoc
+++ b/components/camel-hdfs/src/main/docs/hdfs-component.adoc
@@ -14,7 +14,7 @@ for this component:
 ------------------------------------------------------------
 <dependency>
     <groupId>org.apache.camel</groupId>
-    <artifactId>camel-hdfs2</artifactId>
+    <artifactId>camel-hdfs</artifactId>
     <version>x.x.x</version>
     <!-- use the same version as your Camel core version -->
 </dependency>
diff --git a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java
similarity index 95%
rename from platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java
rename to platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java
index b6bfb5d..724e49a 100644
--- a/platforms/spring-boot/components-starter/camel-hdfs2-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java
+++ b/platforms/spring-boot/components-starter/camel-hdfs-starter/src/main/java/org/apache/camel/component/hdfs2/springboot/HdfsComponentConfiguration.java
@@ -26,13 +26,13 @@ import org.springframework.boot.context.properties.ConfigurationProperties;
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
 @Generated("org.apache.camel.maven.packaging.SpringBootAutoConfigurationMojo")
-@ConfigurationProperties(prefix = "camel.component.hdfs2")
+@ConfigurationProperties(prefix = "camel.component.hdfs")
 public class HdfsComponentConfiguration
         extends
             ComponentConfigurationPropertiesCommon {
 
     /**
      * Whether to enable auto configuration of the hdfs2 component. This is
      * enabled by default.
      */
     private Boolean enabled;
@@ -26,13 +26,13 @@ import org.springframework.boot.context.properties.ConfigurationProperties;
 
     /**
-     * Whether to enable auto configuration of the hdfs2 component. This is
+     * Whether to enable auto configuration of the hdfs component. This is
      * enabled by default.
      */